# STEF: Submission TEst Framework

This is a testing framework for stdin/stdout. Its intended use is testing submissions of students automatically. 
Please be aware that this is very work in progress and not supported in any way. 

